# # From https://github.com/tholum/bluez/blob/master/blue.py
#
# import os
# import struct
# import time
# from ctypes import (CDLL, get_errno)
# from ctypes.util import find_library
# import numpy as np
# from socket import (
#     socket,
#     AF_BLUETOOTH,
#     SOCK_RAW,
#     BTPROTO_HCI,
#     SOL_HCI,
#     HCI_FILTER,
# )
# from ThreadUnit import ThreadUnit
# from RobotLogger import robot_logger as logger
#
#
# class BluetoothInitError(Exception):
#     pass
#
#
# class Bluetooth:
#
#     def __init__(self):
#
#         #  Reset the state of the bluetooth hardware, as it can be locked.
#         os.system("sudo service bluetooth restart")
#         os.system("sudo hciconfig hci0 down")
#         os.system("sudo hciconfig hci0 up")
#
#         self.btlib = find_library("bluetooth")
#         self.bluez = CDLL(self.btlib, use_errno=True)
#
#         self.dev_id = self.bluez.hci_get_route(None)
#
#         self.sock = socket(AF_BLUETOOTH, SOCK_RAW, BTPROTO_HCI)
#         self.sock.bind((self.dev_id,))
#
#         e = self.bluez.hci_le_set_scan_parameters(self.sock.fileno(), 0, 0x10, 0x10, 0, 0, 1000)
#         if e < 0:
#             # occurs when scanning is still enabled from previous call
#             logger.warning("Bluetooth: set scan parameters failed")
#             raise BluetoothInitError
#
#         self.hci_filter = struct.pack(
#             "<IQH",
#             0x00000010,
#             0x4000000000000000,
#             0
#         )
#         self.sock.setsockopt(SOL_HCI, HCI_FILTER, self.hci_filter)
#
#     def enable_socket(self, activate=True):
#         err = self.bluez.hci_le_set_scan_enable(
#             self.sock.fileno(),
#             int(activate),  # 1 - turn on;  0 - turn off
#             0,  # 0-filtering disabled, 1-filter out duplicates
#             1000  # timeout
#         )
#         return err
#
#     def pop_bt_rssi(self, timeout, mac_addr):
#         # Bluetooth scan returns lower case MAC addresses, so make sure the
#         # tested MAC address is lower case for comparison
#         mac_addr = mac_addr.lower()
#
#         # Return one RSSI value corresponding to the correct MAC address,
#         # or None if timeout is passed
#         tick = time.time()
#         self.sock.settimeout(timeout)
#         while time.time() - tick < timeout:
#             try:
#                 data = self.sock.recv(1024)
#                 addr = ':'.join("{0:02x}".format(x) for x in data[12:6:-1])
#                 if addr == mac_addr:
#                     return [data[-1]]
#             except:
#                 pass
#         return None
#
#     # not used anymore, since we use a real thread to pop values.
#     def scan_bluetooth(self, mac_addr):
#         # Read a first value, with a timeout of 3 seconds
#         bt_rssi = self.pop_bt_rssi(3, mac_addr)
#         if bt_rssi is None:
#             return None
#
#         # Read more values, but do not wait
#         bt_rssi = [bt_rssi]
#         while True:
#             next = self.pop_bt_rssi(5e-3, mac_addr)
#             if next is None:
#                 break
#             else:
#                 bt_rssi.append(next)
#
#         # Return all values that were read
#         # (but no more than 20 values)
#         return bt_rssi[-20:]
#
#
# if __name__ == "__main__":
#
#     bluetooth = Bluetooth()
#     mac_addr = "68:76:4F:EF:8A:EC"
#     bluetooth_thread = ThreadUnit(lambda: bluetooth.pop_bt_rssi(1,
#                                                                 mac_addr),
#                                   read_period=1e-2)
#     bluetooth.enable_socket(True)
#     bluetooth_thread.start()
#
#     for i in range(10):
#         time.sleep(1)
#         print(bluetooth_thread.collect_measurements())
#
#     bluetooth_thread.stop()
#
#
