# From WaveShare examples

# NeoPixel library strandtest example
# Author: Tony DiCola (tony@tonydicola.com)
#
# Direct port of the Arduino NeoPixel library strandtest example.  Showcases
# various animations on a strip of NeoPixels.
import time

from rpi_ws281x import Adafruit_NeoPixel, Color
import numpy as np
from RobotLogger import robot_logger as logger


# LED strip configuration:
LED_COUNT      = 4      # Number of LED pixels.
LED_PIN        = 18      # GPIO pin connected to the pixels (must support PWM!).
LED_FREQ_HZ    = 800000  # LED signal frequency in hertz (usually 800khz)
LED_DMA        = 5       # DMA channel to use for generating signal (try 5)
LED_BRIGHTNESS = 255     # Set to 0 for darkest and 255 for brightest
LED_INVERT     = False   # True to invert the signal (when using NPN transistor level shift)
LED_CHANNEL    = 0


def colors_by_name(color_name: str):
    colors = {
        "white": [[1., 1., 1.]] * 4,
        "black": [
            [0., 0., 1.], [1., 1., 1.], [1., 1., 1.], [1., 0., 0.]
        ],
        "red": [[1., 0., 0.]] * 4,
        "blue": [[0., 0., 1.]] * 4,
        "green": [[0., 1., 0.]] * 4,
        "magenta": [[1., 0., 1.]] * 4,
        "yellow": [[1., 1., 0.]] * 4,
        "orange": [[1., .5, 0.]] * 4,
    }.get(color_name, 1)
    return colors


class LedStripe:
    def __init__(self):
        logger.debug("init LedStripe")
        self.leds = Adafruit_NeoPixel(LED_COUNT, LED_PIN, LED_FREQ_HZ, LED_DMA, LED_INVERT, LED_BRIGHTNESS)
        self.leds.begin()

    def set_led_colors(self, colors):
        # colors is an 4x3 array of float between 0 and 1
        for i, x in enumerate(colors):
            if len(x) != 3:
                raise ValueError('Colors must be 3-element arrays of floats')
            x = [int(max(0., min(1., xk)) * 255) for xk in x]
            self.leds.setPixelColor(3-i, Color(x[0], x[1], x[2]))
        self.leds.show()

    def switch_off(self):
        self.set_led_colors(np.zeros((4, 3)))
