# try:
#     from gpiozero import TonalBuzzer
#
#     has_tone = True
# except ImportError:
from gpiozero import Buzzer as TonalBuzzer

has_tone = False

import threading
import time

BUZZER_PIN = 4


class Buzzer:
    def __init__(self, buzzer_pin=BUZZER_PIN):
        self._buzzer = TonalBuzzer(buzzer_pin)
        self.boot_notes = [
            220, 440, 880
        ]
        self.boot_tempo = [5, 5, 7]
        self.melody_thread = None

    def connection_jingle(self):
        if has_tone:
            self.play(self.boot_notes, self.boot_tempo)

    def disconnection_jingle(self):
        if has_tone:
            self.play(self.boot_notes[::-1], self.boot_tempo)

    def _play(self, melody: list, tempo: list, pace=0.800):
        for note, _tempo in zip(melody, tempo):
            note_duration = pace / _tempo
            self._buzzer.play(note)
            time.sleep(note_duration)
        self._buzzer.stop()

    def _buz(self, duration=.5):
        self._buzzer.on()
        time.sleep(duration)
        self._buzzer.off()

    def buz(self, tone):
        if tone:
            # if has_tone:
            #     self._buzzer.play(440)
            # else:
            self._buzzer.on()
        else:
            # if has_tone:
            #     self._buzzer.stop()
            # else:
            if self._buzzer.pin is not None:
                    # do turn off buzzer only if it was not closed before (in
                    # such case pin is None)
                    self._buzzer.off()

    def play(self, melody: list, tempo: list, pace=0.800):
        if has_tone:
            self.melody_thread = threading.Thread(
                target=self._play, args=(melody, tempo, pace)
            )
        else:
            self.melody_thread = threading.Thread(target=self._buz)
        self.melody_thread.run()

    def stop(self):
        if has_tone:
            self._buzzer.stop()
        else:
            self._buzzer.off()

    def close(self):
        self._buzzer.close()
