# ROBOT CODE
"""
Create a logger for the robot
"""
import os
import logging
from logging.handlers import RotatingFileHandler
import sys

ROBOT_LOGS = "/home/pi/AlphaI/robot.log"


# A class to avoid "NameError: name 'open' is not defined" when closing
# AlphAI program abruptly (not clear why we get this error though)
class CarefulLogger(logging.Logger):

    def __init__(self, *args, **kwargs):
        self._closed = False
        super().__init__(*args, **kwargs)

    def _log(self, *args, **kwargs):
        if self._closed:
            return
        super()._log(*args, **kwargs)

    def __del__(self):
        self._closed = True


# Logger object
# robot_logger = logging.getLogger()
robot_logger = CarefulLogger("AlphAI")
robot_logger.setLevel(logging.DEBUG)

# Handler for saving to file (DEBUG level)
if not os.path.isfile(ROBOT_LOGS):
    open(ROBOT_LOGS, 'w')
file_handler = RotatingFileHandler(
    ROBOT_LOGS, maxBytes=0xfffff, backupCount=5
)  # 1 Mio - 1 o, 5 old log files
_format = logging.Formatter(
    '[%(levelname)s] %(asctime)s: %(message)s'
)
file_handler.setFormatter(_format)
robot_logger.addHandler(file_handler)

# Handler for displaying entries to console (also DEBUG level)
std_handler = logging.StreamHandler(sys.stdout)
robot_logger.addHandler(std_handler)
