import serial
import time
from RobotLogger import robot_logger as logger


class CommunicationSerial:
    def __init__(self):
        # TODO: Vianney add comments and links to related documentation
        self.dwm = None  # type: serial.Serial
        self.mode = None
        self.last_dist = 0

    # minicom requires pressing Enter twice to enter shell mode.
    def enable_uwb(self, enable):
        # type: (bool) -> bool
        if enable:
            try:
                self.dwm = serial.Serial(
                    port="/dev/ttyACM0", timeout=0, baudrate=115200
                )  # TODO: adapt for new raspberry pi zero 2: ttyAMA0
                t_end = time.time() + 20
                self.mode = "not_started"
                ok = False
                while time.time() < t_end and not ok:
                    self.send_enter()
                    time.sleep(2)
                    mode = self.read_mode()
                    ok = mode in ["waiting", "reading_lec"]
                return ok
            except:
                return False
        else:
            if self.dwm:
                self.use_uwb(False)
                self.dwm.close()
                self.dwm = None
                return True
            else:
                return False

    # reading values from UWB requires sending the command "lec"
    def use_uwb(self, use=True):
        if self.dwm:
            mode = self.read_mode()
            if use:
                if mode == "waiting":
                    self.send_lec()
                elif mode == "not_started":
                    self.send_enter()
                    self.send_lec()
            else:
                if mode == "reading_lec":
                    self.send_lec()
        else:
            if use:
                raise RuntimeError('Trying to use UBW before communication '
                                   'has been opened. Call enable_uwb first.')

    # once the command "lec" executed, datas come in a specific way
    def read_uwb(self):
        if self.dwm:
            try:
                buffer = self.dwm.readall()
                lines = buffer.decode().split("\r")
                line = lines[len(lines)-2]
                if line:
                    if len(line) >= 20:
                        parse = line.split(",")
                        self.last_dist = float(parse[7])
                        # print("UWB reading: received value", self.last_dist)
                        return self.last_dist
                    else:
                        self.send_lec()
                        logger.info(
                            "UWB reading: no recent value, "
                            "using last one {}".format(self.last_dist)
                        )
                        return self.last_dist
                else:
                    self.send_lec()
                    logger.info("UWB reading: no line detected")
                    return self.last_dist
            except Exception as ex:
                self.dwm.write(b"\r")
                self.dwm.write(b"\r")
                self.dwm.write(b"\r")
                logger.info(
                    "UWB reading: can't read line!, "
                    "using last value {}".format(self.last_dist)
                )
                return self.last_dist
        else:
            logger.warning("not even activated")
            return self.last_dist

    def send_lec(self):
        self.dwm.write(b"l")
        time.sleep(0.1)
        self.dwm.write(b"e")
        time.sleep(0.1)
        self.dwm.write(b"c")
        time.sleep(0.1)
        self.dwm.write(b"\r")

    def send_enter(self):
        self.dwm.write(b"\r")
        time.sleep(0.2)
        self.dwm.write(b"\r")
        time.sleep(0.2)

    def send_test(self):
        self.dwm.write(b"a")
        self.dwm.write(b"\r")
        time.sleep(0.3)  # wait for an answer

    # minicom is hard to handle, since it's supposed to be graphic
    # we need to acknowledge which mode we are in, so we can proceed
    def read_mode(self):
        self.mode = None
        try:
            self.send_test()
            self.dwm.readall()  # Cleaning serial buffer communication
        except ConnectionError:
            pass
        try:
            self.send_test()  # Sending a test instruction
            try:
                buffer = self.dwm.readall()
                line = buffer.decode()
                if line:
                    if ("Command not found." in line
                            and "dwm" in line
                            and "DIST" in line):
                        self.mode = "reading_lec"
                    elif ("Command not found." in line
                            and "dwm" in line
                            and "DIST" not in line):
                        self.mode = "waiting"
                    elif "@" in line:
                        self.mode = "not_started"
                else:
                    self.mode = "broken"
            except ConnectionError:
                pass
        except ConnectionError:
            pass
        return self.mode

